@@ -6,12 +6,11 @@
     Django admin definition for django-geopostcodes.
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 from django.contrib.gis import admin
 from .models import Locality
 
 
-class LocalityAdmin(admin.OSMGeoAdmin):
+class LocalityAdmin(admin.GISModelAdmin):
     list_display = ['id', 'iso', 'country', 'language', 'region1', 'region2',
                     'region3', 'region4', 'locality', 'postcode', 'suburb',
                     'latitude', 'longitude', 'elevation', 'iso2', 'fips',
@@ -23,9 +22,9 @@ class LocalityAdmin(admin.OSMGeoAdmin):
                    'utc',
                    'dst']
     search_fields = ['iso', 'country', 'language', 'region1', 'region2',
-                    'region3', 'region4', 'locality', 'postcode', 'suburb',
-                    'latitude', 'longitude', 'elevation', 'iso2', 'fips',
-                    'nuts', 'hasc', 'stat', 'timezone', 'utc', 'dst']
+                     'region3', 'region4', 'locality', 'postcode', 'suburb',
+                     'latitude', 'longitude', 'elevation', 'iso2', 'fips',
+                     'nuts', 'hasc', 'stat', 'timezone', 'utc', 'dst']
+
 
 admin.site.register(Locality, LocalityAdmin)
-
